* Do-File for descriptive statistics in table 1, 2, 3, and A1
************************************************************
clear
capture log close
set more off

* define global 
local myfiles "path"

* open logfile 
log using "`myfiles'\00_Deskriptionen.log", replace

************************************************************
* Read in data
use "`myfiles'\SUF_VSE_2014_AN_Betrieb.dta", clear

************************************************************
*generate dummy-variable "Low-pay"
drop yniedrig
gen yniedrig = 0 if bruttoyHrdr >= 10.33 
replace yniedrig = 1 if bruttoyHrdr < 10.33

*generate dummy-variable  "Distance to low-pay threshold"
gen distyniedrig = 10.33 - bruttoyHrdr if yniedrig==1
la var distyniedrig "Distance to low-wage threshold"

gen distyML = 8.50 - bruttoyHrdr if yML==1
la var distyML "Distance to minimum wage threshold"

*generate variable "region" 
gen region = .
replace region = 0 if ef4==1 
replace region = 1 if ef4==5
replace region = 2 if ef4==2 | ef4==3 | ef4==6
replace region = 3 if ef4==4
la var region "Region"
la def region 0 "North-West" 1 "North-East" 2 "West" 3 "South"
la val region region

*generate variable "gender distribution"
gen femaledc = .
replace femaledc = 0 if ef12 < 50
replace femaledc = 1 if ef12 >= 50
la var femaledc "Gender distribution"
la def femaledc 0 "More men in company" 1 "More women in company" 
la val femaledc femaledc

*english labels
la var ef10 "Sex"
replace ef10 = 0 if ef10==1
replace ef10 = 1 if ef10==2
la def sex 0 "Male" 1 "Female", replace
la val ef10 sex

la var ef41 "Age (in years)"

gen ef41d = ef41*ef41
la var ef41d "Age (in years squared)"

drop age
gen age = .
replace age = 0 if ef41 >= 18 & ef41 <= 24
replace age = 1 if ef41 >= 25 & ef41 <= 34
replace age = 2 if ef41 >= 35 & ef41 <= 44
replace age = 3 if ef41 >= 45 & ef41 <= 54
replace age = 4 if ef41 >= 55 & ef41 <= 64
replace age = 5 if ef41 >= 65 & !missing(ef41)
la var age "Age"
la def age 0 "18-24" 1 "25-34" 2 "35-44" 3 "45-54" 4 "55-64" 5 "65 and older", replace
la val age age

gen Beruf1=Beruf
drop Beruf
gen Beruf = 0 if Beruf1 == 2
replace Beruf = 1 if Beruf1 == 3 
replace Beruf = 2 if Beruf1 == 4
replace Beruf = 3 if Beruf1 == 1
la var Beruf "Highest education level"
la def Beruf 0 "No vocational training" 1 "Vocational training/ master craftsman" 2 "Polytechnic/ university degree" 3 "Unknown", replace
la val Beruf Beruf

la var ef40 "Tenure (in years)"
gen ef40d = ef40*ef40
la var ef40d "Tenure (in years squared)"

gen tenure = .
replace tenure = 0 if ef40 <= 4
replace tenure = 1 if ef40 > 4 & ef40 < 10
replace tenure = 2 if ef40 >= 10
la var tenure "Tenure"
la def tenure 0 "0-4" 1 "5-9" 2 "10 years and more", replace
la val tenure tenure

la var beschform "Employment state"
replace beschform = 0 if beschform == 1
replace beschform = 1 if beschform == 2
replace beschform = 2 if beschform == 3
la def beschform 0 "Full-time" 1 "Part-time" 2 "Marginal employment", replace
la val beschform beschform

la var Frist "Type of contract"
replace Frist = 0 if Frist == 1
replace Frist = 1 if Frist == 2
la def Frist 0 "Permanent contract" 1 "Fixed-term contract", replace
la val Frist Frist

la var Zeitarbeit "Temporary work"
la def Zeitarbeit 0 "No temporary work" 1 "Temporary work", replace
la val Zeitarbeit Zeitarbeit

replace ef16b = 3 if missing(ef8)
la var ef16b "Collective agreement"
la def ef16b 0 "Company not bound by a collective agreement" 1 "Sectoral collective agreement" 2 "Company collective agreement" 3 "unknown", replace
la val ef16b ef16b
   
la var size "Size of company"
replace size = 5 if missing(ef26Betrieb)
la def size 5 "unknown", modify

la var ef6 "Industry"

gen ef6neu = ef6
drop ef6
gen ef6 = 0 if ef6neu == 1 | ef6neu == 2
replace ef6 = 1 if ef6neu == 5 
replace ef6 = 2 if ef6neu >= 10 &  ef6neu <= 33
replace ef6 = 3 if ef6neu == 35
replace ef6 = 4 if ef6neu == 41 | ef6neu == 43
replace ef6 = 5 if ef6neu == 45 | ef6neu == 46 | ef6neu == 47
replace ef6 = 6 if ef6neu == 49 | ef6neu == 52 | ef6neu == 53
replace ef6 = 7 if ef6neu == 55 | ef6neu == 56
replace ef6 = 8 if ef6neu == 58 | ef6neu == 61
replace ef6 = 9 if ef6neu == 64 | ef6neu == 65
replace ef6 = 10 if ef6neu == 68
replace ef6 = 11 if ef6neu >= 69 &  ef6neu <= 75
replace ef6 = 12 if ef6neu >= 77 &  ef6neu <= 82
replace ef6 = 13 if ef6neu == 84
replace ef6 = 14 if ef6neu == 85
replace ef6 = 15 if ef6neu >= 86 &  ef6neu <= 88
replace ef6 = 16 if ef6neu >= 90 &  ef6neu <= 93
replace ef6 = 17 if ef6neu >= 94 &  ef6neu <= 96


la var ef6 "Industry"
la def ef6 0 "Agriculture, forestry and fishing" 1 "Mining and quarrying" 2 "Manufacturing" 3 "Electricity, gas, steam and water supply" 4 "Construction"  5 "Wholesale and retail trade; repair of motor vehicles" 6 "Transportation and storage" 7 "Accomodation and food service activities" 8 "Information and communication" 9 "Financial and insurance activities" 10 "Real estate activities" 11 "Professional, scientific and technical activities"  12 "Administrative and support service activities" 13 "Public administration and defence; compulsory social security" 14 "Education" 15 "Human Health and social work activities" 16 "Arts, entertainment and recreation" 17 "Other service activities" , replace

la val ef6 ef6
  
***************************************************
*Descriptions 
***************************************************
* Descriptions for thresholds
su yniedrig yML distyniedrig distyML [aweight= b52]

* Descriptions for wages - overall
su bruttoyHrdr [aweight= b52]

* Descriptions for wages - below low-pay threshold	
su bruttoyHrdr if yniedrig==1 [aweight= b52]

* Descriptions for wages - below minimum-wage threshold	
su bruttoyHrdr if yML==1 [aweight= b52]


* Descriptions - overall		
foreach var of varlist ef10 age Beruf tenure beschform Frist Zeitarbeit region femaledc ef16b size ef6 {
                ta `var' [aweight= b52]
				}
				
* Descriptions for wages - below low-pay threshold		
foreach var of varlist ef10 age Beruf tenure beschform Frist Zeitarbeit region femaledc ef16b size ef6 {		
                ta `var' yniedrig [aweight= b52], row nofreq 
				}
				
* Descriptions for wages - below minimum-wage threshold	
foreach var of varlist ef10 age Beruf tenure beschform Frist Zeitarbeit region femaledc ef16b size ef6 {		
                ta `var' yML  [aweight= b52], row nofreq
				}

* Descriptions for groups of workers - overall	
foreach var of varlist ef10 age Beruf tenure beschform Frist Zeitarbeit region femaledc ef16b size ef6 {
                by `var', sort: su bruttoyHrdr [aweight= b52]
				}			
 
* Descriptions for groups of workers - below low-pay threshold			
foreach var of varlist ef10 age Beruf tenure beschform Frist Zeitarbeit region femaledc ef16b size ef6 {
                by `var', sort: su bruttoyHrdr if yniedrig==1 [aweight= b52]
				}	
				
* Descriptions for groups of workers - below minimum-wage threshold		
foreach var of varlist ef10 age Beruf tenure beschform Frist Zeitarbeit region femaledc ef16b size ef6 {
                by `var', sort: su bruttoyHrdr if yML==1 [aweight= b52]
				}
				
* Marginal employment differentiated by industrial sectors
ta ef6 beschform [aweight= b52], row 

* Marginal employment paid below 8.50 euros differentiated by industrial sectors
by ef6, sort: ta beschform  yML [aweight= b52], row 

* Hourly wages of marginal employed differentiated by industrial sectors
by ef6, sort: su bruttoyHrdr if beschform==2 [aweight= b52]

* Hourly wages of marginal employed, who earned less than 8.50 euros, differentiated by industrial sectors
by ef6, sort: su bruttoyHrdr if beschform==2 & yML==1 [aweight= b52]


************************************************************
log close
exit, clear 
