* Do-File for RE-estimations 
************************************************************
clear
capture log close
set more off

* define global
local myfiles "path"

* open logfile 
log using "`myfiles'\01_RE-Schaetzung.log", replace

************************************************************
* Read in data
use "`myfiles'\SUF_VSE_2014_AN_Betrieb", clear

************************************************************
*generate dummy-variable "Low-pay"
drop yniedrig
gen yniedrig = 0 if bruttoyHrdr >= 10.33 
replace yniedrig = 1 if bruttoyHrdr < 10.33

*generate dummy-variable  "Distance to low-pay threshold"
gen distyniedrig = 10.33 - bruttoyHrdr if yniedrig==1
la var distyniedrig "Distance to low-wage threshold"

gen distyML = 8.50 - bruttoyHrdr if yML==1
la var distyML "Distance to minimum wage threshold"

*generate variable "region"  
gen region = .
replace region = 0 if ef4==1 
replace region = 1 if ef4==5
replace region = 2 if ef4==2 | ef4==3 | ef4==6
replace region = 3 if ef4==4
la var region "Region"
la def region 0 "North-West" 1 "North-East" 2 "West" 3 "South"
la val region region

*generate variable "gender distribution"
gen femaledc = .
replace femaledc = 0 if ef12 < 50
replace femaledc = 1 if ef12 >= 50
la var femaledc "Gender distribution"
la def femaledc 0 "more men in company" 1 "more women in company" 
la val femaledc femaledc

*english labels
la var ef10 "Sex"
replace ef10 = 0 if ef10==1
replace ef10 = 1 if ef10==2
la def sex 0 "male" 1 "female", replace
la val ef10 sex

la var ef41 "Age (in years)"

gen ef41d = ef41*ef41
la var ef41d "Age (in years squared)"

gen Beruf1=Beruf
drop Beruf
gen Beruf = 0 if Beruf1 == 2
replace Beruf = 1 if Beruf1 == 3 
replace Beruf = 2 if Beruf1 == 4
replace Beruf = 3 if Beruf1 == 1
la var Beruf "Highest education level"
la def Beruf 0 "No vocational training" 1 "Vocational training/ master craftsman" 2 "Polytechnic/ university degree" 3 "Unknown", replace
la val Beruf Beruf

la var ef40 "Tenure (in years)"
gen ef40d = ef40*ef40
la var ef40d "Tenure (in years squared)"

la var beschform "Employment state"
replace beschform = 0 if beschform == 1
replace beschform = 1 if beschform == 2
replace beschform = 2 if beschform == 3
la def beschform 0 "Full-time" 1 "Part-time" 2 "Marginal employment", replace
la val beschform beschform

la var Frist "Type of contract"
replace Frist = 0 if Frist == 1
replace Frist = 1 if Frist == 2
la def Frist 0 "Permanent contract" 1 "Fixed-term contract", replace
la val Frist Frist

la var Zeitarbeit "Temporary work"
la def Zeitarbeit 0 "No temporary work" 1 "Temporary work", replace
la val Zeitarbeit Zeitarbeit

replace ef16b = 3 if missing(ef8)
la var ef16b "Collective agreement"
la def ef16b 0 "Company not bound by a collective agreement" 1 "Sectoral collective agreement" 2 "Company collective agreement" 3 "unknown", replace
la val ef16b ef16b
   
la var size "Size of company"
replace size = 5 if missing(ef26Betrieb)
la def size 5 "unknown", modify

la var ef6 "Sector"

 
***************************************************
***************************************************
*Multi-level models
***************************************************
***************************************************

***************************************************
*Random intercept-only models  (Jobs, Companies, Sectors)
***************************************************
eststo: xtmelogit yniedrig || ef6: || ef1:, variance

eststo: xtmelogit yML || ef6: || ef1:, variance

eststo: xtmixed distyniedrig || ef6: || ef1:, variance

eststo: xtmixed distyML || ef6: || ef1:, variance

esttab using "`myfiles'\Intercept_only_modell.rtf", se  b(%8.3f) transform(ln*: exp(2*@) 2*exp(2*@)) eqlabels("" "var(Industry)" "var(Company)" "var(Residual)", none) scalars("chi2_c chi2"  "p_c Prob > chi2" ) alignment(c) nonumbers nogaps title(Table: Estimation results for intercept-only models (three-level random intercept models without explanatory variables)) mtitles("Probability of low-wage job" "Probability ofMinimum-wage job" "Distance to low-wage threshold" "Distance to minimum-wage threshold") replace

************************************************************
exit, clear 
