* Do-File for logit- and ols-estimations
************************************************************
clear
capture log close
set more off

* define global
local myfiles "path"

* open logfile 
log using "`myfiles'\02_log_linear_Schaetzung.log", replace

************************************************************
* Read in data
use "`myfiles'\SUF_VSE_2014_AN_Betrieb", clear

************************************************************
*generate dummy-variable "Low-pay"
drop yniedrig
gen yniedrig = 0 if bruttoyHrdr >= 10.33 
replace yniedrig = 1 if bruttoyHrdr < 10.33

*generate dummy-variable  "Distance to low-pay threshold"
gen distyniedrig = 10.33 - bruttoyHrdr if yniedrig==1
la var distyniedrig "Distance to low-wage threshold"

gen distyML = 8.50 - bruttoyHrdr if yML==1
la var distyML "Distance to minimum wage threshold"

*generate variable "region" 
gen region = .
replace region = 0 if ef4==1 
replace region = 1 if ef4==5
replace region = 2 if ef4==2 | ef4==3 | ef4==6
replace region = 3 if ef4==4
la var region "Region"
la def region 0 "Northwest" 1 "Northeast" 2 "West" 3 "South"
la val region region

*generate variable "gender distribution"
gen femaledc = .
replace femaledc = 0 if ef12 < 50
replace femaledc = 1 if ef12 >= 50
la var femaledc "Gender distribution"
la def femaledc 0 "more men in company" 1 "more women in company" 
la val femaledc femaledc

*english labels
la var ef10 "Sex"
replace ef10 = 0 if ef10==1
replace ef10 = 1 if ef10==2
la def sex 0 "Male" 1 "Female", replace
la val ef10 sex

la var ef41 "Age (in years)"

gen ef41d = ef41*ef41
la var ef41d "Age (in years squared)"

gen Beruf1=Beruf
drop Beruf
gen Beruf = 0 if Beruf1 == 2
replace Beruf = 1 if Beruf1 == 3 
replace Beruf = 2 if Beruf1 == 4
replace Beruf = 3 if Beruf1 == 1
la var Beruf "Highest attained education level"
la def Beruf 0 "No vocational training" 1 "Vocational training/ master craftsman" 2 "Polytechnic/ university degree" 3 "Unknown", replace
la val Beruf Beruf

la var ef40 "Tenure (in years)"
gen ef40d = ef40*ef40
la var ef40d "Tenure (in years squared)"

la var beschform "Employment status"
replace beschform = 0 if beschform == 1
replace beschform = 1 if beschform == 2
replace beschform = 2 if beschform == 3
la def beschform 0 "Full-time" 1 "Part-time" 2 "Marginal employment", replace
la val beschform beschform

la var Frist "Type of contract"
replace Frist = 0 if Frist == 1
replace Frist = 1 if Frist == 2
la def Frist 0 "Permanent contract" 1 "Fixed-term contract", replace
la val Frist Frist

la var Zeitarbeit "Temporary vs regular work"
la def Zeitarbeit 0 "Regular work" 1 "Temporary work", replace
la val Zeitarbeit Zeitarbeit

replace ef16b = 3 if missing(ef8)
la var ef16b "Collective agreement"
la def ef16b 0 "Company not bound by a collective agreement" 1 "Company bound by sectoral collective agreement" 2 "Company bound by company collective agreement" 3 "unknown", replace
la val ef16b ef16b
   
la var size "Size of company"
replace size = 5 if missing(ef26Betrieb)
la def size 5 "unknown", modify

la var ef6 "Industry"

gen ef6neu = ef6
drop ef6
gen ef6 = 0 if ef6neu == 1 | ef6neu == 2
replace ef6 = 1 if ef6neu == 5 
replace ef6 = 2 if ef6neu >= 10 &  ef6neu <= 33
replace ef6 = 3 if ef6neu == 35
replace ef6 = 4 if ef6neu == 41 | ef6neu == 43
replace ef6 = 5 if ef6neu == 45 | ef6neu == 46 | ef6neu == 47
replace ef6 = 6 if ef6neu == 49 | ef6neu == 52 | ef6neu == 53
replace ef6 = 7 if ef6neu == 55 | ef6neu == 56
replace ef6 = 8 if ef6neu == 58 | ef6neu == 61
replace ef6 = 9 if ef6neu == 64 | ef6neu == 65
replace ef6 = 10 if ef6neu == 68
replace ef6 = 11 if ef6neu >= 69 &  ef6neu <= 75
replace ef6 = 12 if ef6neu >= 77 &  ef6neu <= 82
replace ef6 = 13 if ef6neu == 84
replace ef6 = 14 if ef6neu == 85
replace ef6 = 15 if ef6neu >= 86 &  ef6neu <= 88
replace ef6 = 16 if ef6neu >= 90 &  ef6neu <= 93
replace ef6 = 17 if ef6neu >= 94 &  ef6neu <= 96


la var ef6 "Industry"
la def ef6 0 "Agriculture, forestry, and fishing" 1 "Mining and quarrying" 2 "Manufacturing" 3 "Electricity, gas, steam, and water supply" 4 "Construction"  5 "Wholesale and retail trade; repair of motor vehicles" 6 "Transportation and storage" 7 "Accommodation and food service activities" 8 "Information and communication" 9 "Financial and insurance activities" 10 "Real estate activities" 11 "Professional, scientific, and technical activities"  12 "Administrative and support service activities" 13 "Public administration and defence; compulsory social security" 14 "Education" 15 "Human health and social work activities" 16 "Arts, entertainment, and recreation" 17 "Other service activities" , replace

la val ef6 ef6
  
***************************************************
*Estimations with clustered standard errors 
***************************************************
logit  yniedrig i.ef10 b1.Beruf ef41 ef41d ef40 ef40d b0.beschform i.Frist i.Zeitarbeit b4.size b3.region b1.ef16b i.femaledc b2.ef6,  vce(cluster ef1)
estimates store Mod1
estat class
estadd scalar Correct_Classification = r(P_corr)
margins, dydx(*) post
estimates store Mod1mfx

logit  yML i.ef10 b1.Beruf ef41 ef41d ef40 ef40d b0.beschform i.Frist i.Zeitarbeit b4.size b3.region b1.ef16b i.femaledc b2.ef6,  vce(cluster ef1)
estimates store Mod2
estat class
estadd scalar Correct_Classification = r(P_corr)
margins, dydx(*) post
estimates store Mod2mfx

regress distyniedrig i.ef10 b1.Beruf ef41 ef41d ef40 ef40d b0.beschform i.Frist i.Zeitarbeit b4.size b3.region b1.ef16b i.femaledc b2.ef6,  vce(cluster ef1)
estimates store Mod3

regress distyML i.ef10 b1.Beruf ef41 ef41d ef40 ef40d b0.beschform i.Frist i.Zeitarbeit b4.size b3.region b1.ef16b i.femaledc b2.ef6,  vce(cluster ef1)
estimates store Mod4

*coefplot Mod1mfx, bylabel("Probability of" "low-wage job") ///
*      || Mod2mfx, bylabel("Probability of" "minimum-wage job")  ///
*	  || Mod3, bylabel("Distance to" "low-wage threshold")  ///
*      || Mod4, bylabel("Distance to" "minimum-wage threshold")  ///
*      ||, keep(1.ef10 ef41 ef41d 0.Beruf 2.Beruf 3.Beruf ef40 ef40d 1.beschform 2.beschform 1.Frist 1.Zeitarbeit 1.region 2.region) headings(0.ef10 = "{bf:Gender}" 1.Beruf = "{bf:Ausb}") xline(0) coeflabels(, wrap(20)) byopts(xrescale) levels(99.9 99 95) msymbol(d) mfcolor(white) graphregion(color(white))

* Individual determinants
coefplot (Mod1mfx, label("Probability of" "low-wage job")) (Mod2mfx, label("Probability of" "minimum-wage job")), bylabel(Probability) ///
	|| (Mod3, label("Low-wage threshold")) (Mod4, label("Minimum-wage threshold")), bylabel(Distance) ///
    ||, keep(*.ef10 ef41 ef41d *.Beruf ef40 ef40d *.beschform *.Frist *.Zeitarbeit) headings(1.ef10 = "{bf:Gender} (Ref: Male)" ef41 = "{bf:Age}" 0.Beruf = "{bf:Highest attained education level} (Ref: Vocational training, master craftsman)" ef40 = "{bf:Tenure}" 1.beschform = "{bf:Employment status} (Ref: Full-time)" 1.Frist = "{bf:Type of contract} (Ref: Permanent contract)" 1.Zeitarbeit = "{bf:Temporary vs. regular work} (Ref: Regular work)" ,  wrap(50)) xline(0) byopts(xrescale) levels(99.9 99 95) ciopts(lwidth(*1 *3 *5)) mfcolor(white) graphregion(color(white)) msymbol(Oh D) coeflabels(, labsize(small)) 
graph export "`myfiles'\02a_Indiv.png", replace width(2000)
	
* Company-level determinants
coefplot (Mod1mfx, label("Probability of" "low-wage job")) (Mod2mfx, label("Probability of" "minimum-wage job")), bylabel(Probability) ///
	|| (Mod3, label("Low-wage threshold")) (Mod4, label("Minimum-wage threshold")), bylabel(Distance) ///
    ||, keep(*.size *.region *.ef16b *.femaledc) headings(1.size = "{bf:Size of company} (Ref: 250>)" 0.region = "{bf:Region} (Ref: South)" 0.ef16b = "{bf:Presence or type of collective agreement} (Ref: Sectoral collective agreement)"  1.femaledc = "{bf:Gender distribution} (Ref: More men in company)", wrap(50)) xline(0) byopts(xrescale) levels(99.9 99 95) mfcolor(white) graphregion(color(white)) msymbol(Oh) coeflabels(, labsize(small)) 
graph export "`myfiles'\02b_Comp.png", replace width(2000)
	
* Sectoral determinants	
coefplot (Mod1mfx, label("Probability of" "low-wage job")) (Mod2mfx, label("Probability of" "minimum-wage job")), bylabel(Probability) ///
	|| (Mod3, label("Low-wage threshold")) (Mod4, label("Minimum-wage threshold")), bylabel(Distance) ///
    ||, keep(*ef6) headings(0.ef6 = "{bf:Industry} (Ref: Manufacturing)") xline(0) byopts(xrescale) levels(99.9 99 95) mfcolor(white) graphregion(color(white)) msymbol(Oh) coeflabels(, labsize(small)) 
graph export "`myfiles'\02c_Sect.png", replace width(2000)
	  
* Corresponding table	  
esttab Mod1mfx Mod2mfx Mod3 Mod4 using "`myfiles'\log_linear_Schaetzung.rtf", se label r2 pr2 b(%8.3f) aic bic star(* 0.10 ** 0.05 *** 0.01) scalars(chi2 p Correct_Classification ll) title(Table: Estimates on individual and structural determinants) mtitles("Probability of low-wage job" "Probability of minimum-wage job" "Distance to low-wage threshold" "Distance to minimum-wage threshold") alignment(c) nonumbers nogaps replace

************************************************************
log close
exit, clear 
